@@ -9,6 +9,7 @@ from typing import Callable, Dict, List, Optional
 
 import vlc
 from notifypy import Notify
+from tqdm import tqdm
 
 from exclock.util import get_real_sound_filename
 
@@ -112,27 +113,24 @@ class ClockTimer:
     def run_once(self, count: int) -> None:
         sounds = self.sorted_sounds
 
-        t = 0
         ps = []
 
-        while True:
-            for sec, sound in sounds.items():
-                if t == sec:
-                    notification = Notify()
-                    notification.application_name = "Exclock"
-                    notification.title = self.title
-                    notification.message = inner_str(sound.message, {"count": count})
+        secs = list(sounds.keys())
+        for i, (sec, sound) in enumerate(sounds.items()):
+            spend_time = secs[i] - (0 if i == 0 else secs[i - 1])
+            for _ in tqdm(range(spend_time)):
+                time_sleep(1)
 
-                    notification.send()
+            notification = Notify()
+            notification.application_name = "Exclock"
+            notification.title = self.title
+            notification.message = inner_str(sound.message, {"count": count})
+            notification.send()
 
-                    ps.append(sound.run())
-                    sound.confirm_f()
+            print(notification.message)
 
-            if len(sounds) == len(ps) and any_ended_sounds(ps):
-                break
-
-            t += 1
-            time_sleep(1)
+            ps.append(sound.run())
+            sound.confirm_f()
 
         while not any_ended_sounds(ps):
             time_sleep(1)
